Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Confirm ¶
Confirm prompts the user for confirmation with the given label. msg is expected to be a simple string such as "canceled" or "skipped" and will not be handled as an ignoresync error.
func NewPromptError ¶
NewPromptError constructs a prompt error wrapping optional underlying error.
Types ¶
type Error ¶
Error represents an error that occurred in the prompt.
Click to show internal directories.
Click to hide internal directories.